@@ -6,9 +6,11 @@
 
 import json
 import re
+import types
 
+from . import validators
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 # constants for DeletionPolicy
 Delete = 'Delete'
@@ -62,23 +64,58 @@ class AWSObject(object):
         if '_AWSObject__initialized' not in self.__dict__:
             return dict.__setattr__(self, name, value)
         elif name in self.propnames:
-            # Check the type of the object and compare against what
-            # we were expecting. Special case AWS helper functions.
+            # Check the type of the object and compare against what we were
+            # expecting.
             expected_type = self.props[name][0]
-            if isinstance(value, expected_type) or \
-                    isinstance(value, AWSHelperFn):
+
+            # If the value is a AWSHelperFn we can't do much validation
+            # we'll have to leave that to Amazon.  Maybe there's another way
+            # to deal with this that we'll come up with eventually
+            if isinstance(value, AWSHelperFn):
+                return self.properties.__setitem__(name, value)
+
+            # If it's a function, call it...
+            elif isinstance(expected_type, types.FunctionType):
+                value = expected_type(value)
+                return self.properties.__setitem__(name, value)
+
+            # If it's a list of types, check against those types...
+            elif isinstance(expected_type, list):
+                # If we're expecting a list, then make sure it is a list
+                if not isinstance(value, list):
+                    self._raise_type(name, value, expected_type)
+
+                # Iterate over the list and make sure it matches our
+                # type checks
+                for v in value:
+                    if not isinstance(v, tuple(expected_type)):
+                        self._raise_type(name, v, expected_type)
+                # Validated so assign it
+                return self.properties.__setitem__(name, value)
+
+            # Single type so check the type of the object and compare against
+            # what we were expecting. Special case AWS helper functions.
+            elif isinstance(value, expected_type):
                 return self.properties.__setitem__(name, value)
             else:
-                raise TypeError('%s is %s, expected %s' %
-                                (name, type(value), expected_type))
+                self._raise_type(name, value, expected_type)
+
         raise AttributeError("%s object does not support attribute %s" %
                             (self.type, name))
 
+    def _raise_type(self, name, value, expected_type):
+        raise TypeError('%s is %s, expected %s' %
+                        (name, type(value), expected_type))
+
+    def validate(self):
+        pass
+
     def JSONrepr(self):
         for k, v in self.props.items():
             if v[1] and k not in self.properties:
                 raise ValueError("Resource %s required in type %s" %
                                  (k, self.type))
+        self.validate()
         # If no other properties are set, only return the Type.
         # Mainly used to not have an empty "Properties".
         if self.properties:
@@ -99,17 +136,31 @@ class AWSProperty(AWSObject):
         sup.__init__(None, props=self.props, **kwargs)
 
 
+def validate_pausetime(pausetime):
+    if not pausetime.startswith('PT'):
+        raise ValueError('PauseTime should look like PT#H#M#S')
+    return pausetime
+
+
 class UpdatePolicy(AWSObject):
     props = {
         'MaxBatchSize': (basestring, False),
         'MinInstancesInService': (basestring, False),
-        'PauseTime': (basestring, False),
+        'PauseTime': (validate_pausetime, False),
     }
 
+    valid_update_policies = (
+        'AutoScalingRollingUpdate',
+    )
+
     def __init__(self, name, **kwargs):
         sup = super(UpdatePolicy, self)
         sup.__init__(None, None, name, self.props, **kwargs)
 
+        if name not in self.valid_update_policies:
+            raise ValueError('UpdatePolicy name must be one of %r' % (
+                self.valid_update_policies,))
+
 
 class AWSHelperFn(object):
     def getdata(self, data):
@@ -295,10 +346,10 @@ class Parameter(AWSObject):
         'NoEcho': (bool, False),
         'AllowedValues': (list, False),
         'AllowedPattern': (basestring, False),
-        'MaxLength': (basestring, False),
-        'MinLength': (basestring, False),
-        'MaxValue': (basestring, False),
-        'MinValue': (basestring, False),
+        'MaxLength': (validators.positive_integer, False),
+        'MinLength': (validators.positive_integer, False),
+        'MaxValue': (validators.integer, False),
+        'MinValue': (validators.integer, False),
         'Description': (basestring, False),
         'ConstraintDescription': (basestring, False),
     }
