@@ -4,6 +4,7 @@
 # See LICENSE file for full license.
 
 from . import AWSHelperFn, AWSObject, AWSProperty, Ref
+from .validators import boolean, integer, network_port
 
 
 class Tag(AWSHelperFn):
@@ -14,7 +15,7 @@ class Tag(AWSHelperFn):
         return self.data
 
 
-class CustomGateway(AWSObject):
+class CustomerGateway(AWSObject):
     props = {
         'BgpAsn': (int, True),
         'IpAddress': (basestring, True),
@@ -22,8 +23,8 @@ class CustomGateway(AWSObject):
     }
 
     def __init__(self, name, **kwargs):
-        self.type = "AWS::EC2::CustomGateway"
-        sup = super(CustomGateway, self)
+        self.type = "AWS::EC2::CustomerGateway"
+        sup = super(CustomerGateway, self)
         sup.__init__(name, self.type, "Properties", self.props, **kwargs)
 
 
@@ -31,9 +32,9 @@ class DHCPOptions(AWSObject):
     props = {
         'DomainName': (basestring, False),
         'DomainNameServers': (list, False),
-        'NTPServers': (basestring, False),
-        'NetbiosNameServers': (basestring, False),
-        'NetbiosNodeType': (list, False),
+        'NetbiosNameServers': (list, False),
+        'NetbiosNodeType': (int, False),
+        'NTPServers': (list, False),
         'Tags': (list, False),
     }
 
@@ -69,9 +70,36 @@ class EIPAssociation(AWSObject):
         sup.__init__(name, self.type, "Properties", self.props, **kwargs)
 
 
+class EBSBlockDevice(AWSProperty):
+    props = {
+        'DeleteOnTermination': (bool, False),
+        'Iops': (int, False),  # Conditional
+        'SnapshotId': (basestring, False),  # Conditional
+        'VolumeSize': (integer, False),  # Conditional
+        'VolumeType': (basestring, False),
+    }
+
+
+class BlockDeviceMapping(AWSProperty):
+    props = {
+        'DeviceName': (basestring, True),
+        'Ebs': (EBSBlockDevice, False),      # Conditional
+        'NoDevice': (dict, False),
+        'VirtualName': (basestring, False),  # Conditional
+    }
+
+
+class MountPoint(AWSProperty):
+    props = {
+        'Device': (basestring, True),
+        'VolumeId': (basestring, True),
+    }
+
+
 class Instance(AWSObject):
     props = {
         'AvailabilityZone': (basestring, False),
+        'BlockDeviceMappings': (list, False),
         'DisableApiTermination': (bool, False),
         'EbsOptimized': (bool, False),
         'IamInstanceProfile': (basestring, False),
@@ -79,7 +107,7 @@ class Instance(AWSObject):
         'InstanceType': (basestring, True),
         'KernelId': (basestring, False),
         'KeyName': (basestring, False),
-        'Monitoring': (basestring, False),
+        'Monitoring': (boolean, False),
         'NetworkInterfaces': (list, False),
         'PlacementGroupName': (basestring, False),
         'PrivateIpAddress': (basestring, False),
@@ -100,13 +128,6 @@ class Instance(AWSObject):
         sup.__init__(name, self.type, "Properties", self.props, **kwargs)
 
 
-class MountPoint(AWSProperty):
-    props = {
-        'Device': (basestring, True),
-        'VolumeId': (basestring, True),
-    }
-
-
 class InternetGateway(AWSObject):
     props = {
         'Tags': (list, False),
@@ -146,14 +167,14 @@ class PortRange(AWSProperty):
 
 class NetworkAclEntry(AWSObject):
     props = {
+        'CidrBlock': (basestring, True),
+        'Egress': (boolean, True),
+        'Icmp': (ICMP, False),  # Conditional
         'NetworkAclId': (basestring, True),
-        'RuleNumber': (int, True),
+        'PortRange': (PortRange, True),
         'Protocol': (int, True),
         'RuleAction': (basestring, True),
-        'Egress': (basestring, True),
-        'CidrBlock': (basestring, True),
-        'Icmp': (ICMP, True),
-        'PortRange': (PortRange, True),
+        'RuleNumber': (int, True),
     }
 
     def __init__(self, name, **kwargs):
@@ -207,12 +228,20 @@ class RouteTable(AWSObject):
 
 class SecurityGroupEgress(AWSObject):
     props = {
-        'GroupId': (basestring, True),
-        'IpProtocol': (basestring, True),
         'CidrIp': (basestring, False),
         'DestinationSecurityGroupId': (basestring, False),
-        'FromPort': (basestring, True),
-        'ToPort': (basestring, True),
+        'FromPort': (network_port, True),
+        'GroupId': (basestring, False),
+        'IpProtocol': (basestring, True),
+        'ToPort': (network_port, True),
+        #
+        # Workaround for a bug in CloudFormation and EC2 where the
+        # DestinationSecurityGroupId property is ignored causing
+        # egress rules targeting a security group to be ignored.
+        # Using SourceSecurityGroupId instead works fine even in
+        # egress rules. AWS have known about this bug for a while.
+        #
+        'SourceSecurityGroupId': (basestring, False),
     }
 
     def __init__(self, name, **kwargs):
@@ -223,15 +252,15 @@ class SecurityGroupEgress(AWSObject):
 
 class SecurityGroupIngress(AWSObject):
     props = {
+        'CidrIp': (basestring, False),
+        'FromPort': (network_port, False),
         'GroupName': (basestring, False),
         'GroupId': (basestring, False),
         'IpProtocol': (basestring, True),
-        'CidrIp': (basestring, False),
         'SourceSecurityGroupName': (basestring, False),
         'SourceSecurityGroupId': (basestring, False),
         'SourceSecurityGroupOwnerId': (basestring, False),
-        'FromPort': (basestring, False),
-        'ToPort': (basestring, False),
+        'ToPort': (network_port, False),
     }
 
     def __init__(self, name, **kwargs):
@@ -242,13 +271,13 @@ class SecurityGroupIngress(AWSObject):
 
 class SecurityGroupRule(AWSProperty):
     props = {
-        'IpProtocol': (basestring, True),
         'CidrIp': (basestring, False),
-        'SourceSecurityGroupName': (basestring, False),
+        'FromPort': (network_port, True),
+        'IpProtocol': (basestring, True),
         'SourceSecurityGroupId': (basestring, False),
+        'SourceSecurityGroupName': (basestring, False),
         'SourceSecurityGroupOwnerId': (basestring, False),
-        'FromPort': (basestring, True),
-        'ToPort': (basestring, True),
+        'ToPort': (network_port, True),
     }
 
 
@@ -348,8 +377,8 @@ class VPC(AWSObject):
 
 class VPCDHCPOptionsAssociation(AWSObject):
     props = {
-        'VpcId': (basestring, True),
         'DhcpOptionsId': (basestring, True),
+        'VpcId': (basestring, True),
     }
 
     def __init__(self, name, **kwargs):
@@ -360,8 +389,8 @@ class VPCDHCPOptionsAssociation(AWSObject):
 
 class VPCGatewayAttachment(AWSObject):
     props = {
-        'VpcId': (basestring, True),
         'InternetGatewayId': (basestring, False),
+        'VpcId': (basestring, True),
         'VpnGatewayId': (basestring, False),
     }
 
