@@ -4,6 +4,7 @@
 # See LICENSE file for full license.
 
 from . import AWSObject, AWSProperty
+from .validators import integer_range, positive_integer, network_port
 
 
 class AppCookieStickinessPolicy(AWSProperty):
@@ -15,11 +16,13 @@ class AppCookieStickinessPolicy(AWSProperty):
 
 class HealthCheck(AWSProperty):
     props = {
-        'HealthyThreshold': (basestring, True),
-        'Interval': (basestring, True),
+        # XXX I don't actually know what the max is on healthy threshold. 20
+        # seems reasonable?
+        'HealthyThreshold': (integer_range(2, 20), True),
+        'Interval': (positive_integer, True),
         'Target': (basestring, True),
-        'Timeout': (basestring, True),
-        'UnhealthyThreshold': (basestring, True),
+        'Timeout': (positive_integer, True),
+        'UnhealthyThreshold': (positive_integer, True),
     }
 
 
@@ -32,9 +35,9 @@ class LBCookieStickinessPolicy(AWSProperty):
 
 class Listener(AWSProperty):
     props = {
-        'InstancePort': (basestring, True),
+        'InstancePort': (network_port, True),
         'InstanceProtocol': (basestring, False),
-        'LoadBalancerPort': (basestring, True),
+        'LoadBalancerPort': (network_port, True),
         'PolicyNames': (list, False),
         'Protocol': (basestring, True),
         'SSLCertificateId': (basestring, False),
@@ -43,9 +46,9 @@ class Listener(AWSProperty):
 
 class Policy(AWSProperty):
     props = {
-        'Attributes': (dict, False),
+        'Attributes': ([dict], False),
         'InstancePorts': (list, False),
-        'LoadBalancerPorts': (list, True),
+        'LoadBalancerPorts': (list, False),
         'PolicyName': (basestring, True),
         'PolicyType': (basestring, True),
     }
@@ -54,7 +57,7 @@ class Policy(AWSProperty):
 class LoadBalancer(AWSObject):
     props = {
         'AppCookieStickinessPolicy': (list, False),
-        'AvailabilityZones': (basestring, False),
+        'AvailabilityZones': (list, False),
         'HealthCheck': (HealthCheck, False),
         'Instances': (list, False),
         'LBCookieStickinessPolicy': (list, False),
