@@ -4,6 +4,12 @@
 # See LICENSE file for full license.
 
 from . import AWSHelperFn, AWSObject
+from .validators import integer
+try:
+    from awacs.aws import Policy
+    policytypes = (dict, Policy)
+except ImportError:
+    policytypes = dict,
 
 
 Active = "Active"
@@ -12,7 +18,7 @@ Inactive = "Inactive"
 
 class AccessKey(AWSObject):
     props = {
-        'Serial': (basestring, False),
+        'Serial': (integer, False),
         # XXX - Is Status required? Docs say yes, examples say no
         'Status': (basestring, False),
         'UserName': (basestring, True),
@@ -27,7 +33,7 @@ class AccessKey(AWSObject):
 class BasePolicy(AWSObject):
     props = {
         'Groups': (list, False),
-        'PolicyDocument': (dict, True),
+        'PolicyDocument': (policytypes, True),
         'PolicyName': (basestring, True),
         'Roles': (list, False),
         'User': (list, False),
@@ -79,7 +85,7 @@ class InstanceProfile(AWSObject):
 
 class Role(AWSObject):
     props = {
-        'AssumeRolePolicyDocument': (dict, True),
+        'AssumeRolePolicyDocument': (policytypes, True),
         'Path': (basestring, True),
         'Policies': (list, False),
     }
