@@ -3,7 +3,8 @@
 #
 # See LICENSE file for full license.
 
-from . import AWSObject, AWSProperty
+from . import AWSHelperFn, AWSObject, AWSProperty
+from .validators import boolean
 
 
 class DBInstance(AWSObject):
@@ -24,11 +25,12 @@ class DBInstance(AWSObject):
         'LicenseModel': (basestring, False),
         'MasterUsername': (basestring, True),
         'MasterUserPassword': (basestring, True),
-        'MultiAZ': (basestring, False),
+        'MultiAZ': (boolean, False),
         'Port': (basestring, False),
         'PreferredBackupWindow': (basestring, False),
         'PreferredMaintenanceWindow': (basestring, False),
         'Tags': (list, False),
+        'VPCSecurityGroups': ([basestring, AWSHelperFn], False),
     }
 
     def __init__(self, name, **kwargs):
