@@ -4,11 +4,17 @@
 # See LICENSE file for full license.
 
 from . import AWSObject
+from .validators import integer
+try:
+    from awacs.aws import Policy
+    policytypes = (dict, Policy)
+except ImportError:
+    policytypes = dict,
 
 
 class Queue(AWSObject):
     props = {
-        'VisibilityTimeout': (basestring, False),
+        'VisibilityTimeout': (integer, False),
     }
 
     def __init__(self, name, **kwargs):
@@ -19,7 +25,7 @@ class Queue(AWSObject):
 
 class QueuePolicy(AWSObject):
     props = {
-        'PolicyDocument': (dict, False),
+        'PolicyDocument': (policytypes, False),
         'Queues': (list, True),
     }
 
